@@ -422,6 +422,12 @@ main(int argc, char* argv[])
   bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
   textdomain(GETTEXT_PACKAGE);
 
+  // Set the locale for any streams to the user's current locale,
+  // We should not rely on the default locale of 
+  // any streams (we should always do an explicit imbue()), 
+  // but this is maybe a good default in case we forget.
+  std::locale::global(std::locale(""));
+
   Glom::libglom_init(); //Also initializes python.
    
 #ifdef GLOM_ENABLE_MAEMO
@@ -533,8 +539,26 @@ main(int argc, char* argv[])
     {
       //Get a URI (file://something) from the filepath:
       Glib::RefPtr<Gio::File> file = Gio::File::create_for_commandline_arg(input_uri);
-      if(file)
-        input_uri = file->get_uri(); 
+      
+      if(!file->query_exists())
+      {
+        std::cerr << _("Glom: The file does not exist.") << std::endl;
+        
+        std::cerr << std::endl << context.get_help() << std::endl;
+        return -1;
+      }
+      
+      const Gio::FileType file_type = file->query_file_type();
+      if(file_type == Gio::FILE_TYPE_DIRECTORY)
+      {
+        std::cerr << _("Glom: The file path is a directory instead of a file.") << std::endl;
+        
+        std::cerr << std::endl << context.get_help() << std::endl;
+        return -1;
+      }
+      
+      input_uri = file->get_uri();
+
       //std::cout << "URI = " << input_uri << std::endl;
     }
 
